cmc/cleberg.net

My personal web garden & blog.

clone: git clone https://gitbay.org/cmc/cleberg.net.git

ce03860635f7bc1d365cedc0416f3ae376e86204

verified · cmc

author: Christian Cleberg <hello@cleberg.net> · 2026-03-11T05:06:39Z

Remove about page and services route; merge services into apps
 content/about/index.org    |  1 +
 content/apps/index.org     | 93 ++++++++++++++++++++++++++++++++++++++++++++++
 content/services/index.org |  1 +
 publish.el                 | 28 +++++++-------
 4 files changed, 109 insertions(+), 14 deletions(-)

diff --git a/content/about/index.org b/content/about/index.org
index 895057d..82981bd 100644
--- a/content/about/index.org
+++ b/content/about/index.org
@@ -1,5 +1,6 @@
 #+title: about
 #+slug: index
+#+options: toc:nil
 
 Hey, I'm Christian.
 
diff --git a/content/apps/index.org b/content/apps/index.org
new file mode 100644
index 0000000..6655593
--- /dev/null
+++ b/content/apps/index.org
@@ -0,0 +1,93 @@
+#+title: apps
+#+slug: index
+#+options: toc:nil
+
+* iOS Apps
+
+Small apps I've built for iOS. Fully offline. No ads, no accounts, no data
+collection.
+
+#+begin_export html
+<div class="app-card">
+  <a href="https://apps.apple.com/app/daybyday"><img class="app-icon" src="https://img.cleberg.net/apps/daybyday.png" alt="DayByDay icon"></a>
+  <div class="app-info">
+    <span class="app-title">Day By Day</span>
+    <span class="app-subtitle">Learn days, months & seasons!</span>
+    <div class="app-links">
+      <a href="https://apps.apple.com/app/daybyday">App Store</a> &middot;
+      <a href="https://github.com/ccleberg/DayByDay">GitHub</a>
+    </div>
+  </div>
+</div>
+
+<div class="app-card">
+  <a href="https://apps.apple.com/app/space-explorers"><img class="app-icon" src="https://img.cleberg.net/apps/spaceexplorers.png" alt="Space Explorers icon"></a>
+  <div class="app-info">
+    <span class="app-title">Space Explorers</span>
+    <span class="app-subtitle">Explore the galaxy and learn!</span>
+    <div class="app-links">
+      <a href="https://apps.apple.com/app/space-explorers">App Store</a> &middot;
+      <a href="https://github.com/ccleberg/SpaceExplorers">GitHub</a>
+    </div>
+  </div>
+</div>
+
+<div class="app-card">
+  <a href="https://apps.apple.com/app/domaindig"><img class="app-icon" src="https://img.cleberg.net/apps/domaindig.png" alt="DomainDig icon"></a>
+  <div class="app-info">
+    <span class="app-title">Domain Dig</span>
+    <span class="app-subtitle">DNS lookup & SSL certificate checker</span>
+    <div class="app-links">
+      <a href="https://apps.apple.com/app/domaindig">App Store</a> &middot;
+      <a href="https://github.com/ccleberg/DomainDig">GitHub</a>
+    </div>
+  </div>
+</div>
+#+end_export
+
+* Web Projects
+
+| Project             | Description                         | Onion Link          |
+|---------------------+-------------------------------------+---------------------|
+| [[https://projects.cleberg.net/401k/][401k]]                | 401k projections                    | [[http://krednuajd2wpt67ozmkollddpbdphpeyh74hbenagzoxqjncrtrgxkid.onion/401k/][401k]]                |
+| [[https://hn.cleberg.net/][hn]]                  | Hacker News proxy                   | [[http://r3yfeffyj7ornpikojmw75u3sn2la7tqnmcmwgv2ov7if24sm5czqeid.onion/][hn]]                  |
+| [[https://projects.cleberg.net/lincoln-crimes/][lincoln-crimes]]      | Lincoln (NE) crimes over time       | [[http://krednuajd2wpt67ozmkollddpbdphpeyh74hbenagzoxqjncrtrgxkid.onion/lincoln-crimes/][lincoln-crimes]]      |
+| [[https://projects.cleberg.net/palettes/][palettes]]            | Color palette generator             | [[http://krednuajd2wpt67ozmkollddpbdphpeyh74hbenagzoxqjncrtrgxkid.onion/palettes/][palettes]]            |
+| [[https://projects.cleberg.net/space-wiki/][space-wiki]]          | Wiki about space-related topics     | [[http://krednuajd2wpt67ozmkollddpbdphpeyh74hbenagzoxqjncrtrgxkid.onion/space-wiki/][space-wiki]]          |
+| [[https://projects.cleberg.net/world-incarceration/][world-incarceration]] | Data on global incarceration        | [[http://krednuajd2wpt67ozmkollddpbdphpeyh74hbenagzoxqjncrtrgxkid.onion/world-incarceration/][world-incarceration]] |
+| [[https://org.cleberg.net/][Org-Live]]            | A basic org-mode editor for the web | [[http://7vsifofpucgi3wva52nbwhwglrmbyxgdapbkkmgniqlsskspux5zocyd.onion][Org-Live]]            |
+
+* Self-Hosted Services
+
+Alternative front-ends, privacy tools, and utilities I self-host. All available
+via clearnet and Tor.
+
+** Alternative Front-Ends
+
+| Service           | Replaces         | Onion Link        |
+|-------------------+------------------+-------------------|
+| [[https://ao.cleberg.net/][AnonymousOverflow]] | StackOverflow    | [[http://7lyqrn4ofxdq7lfporviu44zpc42wooh2bqazfhvpscgwby2vcwldzad.onion][AnonymousOverflow]] |
+| [[https://br.cleberg.net/][BiblioReads]]       | Goodreads        | [[http://pkft6saqbmn6he5g626fphvlijmkdf4rzckjw6r57zsmuqm4ukd6i5ad.onion][BiblioReads]]       |
+| [[https://pin.cleberg.net/][Binternet]]         | Pinterest        | [[http://3rtmxu6slammicquf5cpgiptjpzht3n342vh62utoyxchds5r76tadad.onion][Binternet]]         |
+| [[https://bw.cleberg.net/][BreezeWiki]]        | Fandom           | [[http://z7kc27ceokwgddrcspxx4eb7b6xqmtjj26nohg3wgt6hsnnlfmk4apqd.onion][BreezeWiki]]        |
+| [[https://ld.cleberg.net][LibremDB]]          | IMDb             | [[http://u3tyzuhs7o4hkizpbcxbm5yqzj74bjqb3phfqfszrx4u75dua7lpf7ad.onion][LibremDB]]          |
+| [[https://piped.cleberg.net][Piped]]             | YouTube          | [[http://5ttqjwhhcxh7apxrge5b5cjqceiibrjlqv2hhtmukwfsitbzqk5hh4id.onion][Piped]]             |
+| [[https://rimgo.cleberg.net/][Rimgo]]             | Imgur            | [[http://hcj62a4s6ok23oaa4xjnnvabj2aunod3464iuufh2wtehg2th3rwn3yd.onion][Rimgo]]             |
+| [[https://rd.cleberg.net/][Rural Dictionary]]  | Urban Dictionary | [[http://voyxxivcoupelvedthpbjqsrdhkn4ty7qjurvsif4qbjejnldisqs5ad.onion][Rural Dictionary]]  |
+| [[https://art.cleberg.net/][SkunkyArt]]         | DeviantArt       | [[http://mplqs2jxkjd5wxak3zjv55oxyadf4vwzx6ksgj4ztftndjl6elgsf4qd.onion][SkunkyArt]]         |
+| [[https://small.cleberg.net][Small]]             | Medium           | [[http://w2qsrbzjmlikhwvbhno3qfdjod53iyzlvzjamcvgkcmtbclmdkqerbqd.onion][Small]]             |
+
+** Other Services
+
+| Service        | Description                                       | Onion Link     |
+|----------------+---------------------------------------------------+----------------|
+| [[https://cc.cleberg.net/][CyberChef]]      | The Cyber Swiss Army Knife                        | [[http://gipsohqqcehn4n6smyg5j5aap7ln6lwugyjm2lxyx4vfiwayjhpnodyd.onion][CyberChef]]      |
+| [[https://files.cleberg.net/][FileArchive]]    | An interesting file archive                       | [[http://yt2y635dc6zyxziy5ytkfz36bmkgcxuccq3meom6qp44gjdat54wt5id.onion][FileArchive]]    |
+| [[https://paste.cleberg.net/][FlashPaper]]     | One-time encrypted password/secret sharing        | [[http://ciserod7fbncypo762qcqtowldl3qjhlojfnmguiuvcj3rcyrhqs6ead.onion][FlashPaper]]     |
+| [[https://hat.cleberg.net/][Hat.sh]]         | Simple, fast, secure client-side file encryption  | [[http://jfrkztgin2ngoj2fnssc2m2j2ycpchmrhzhudaucgvaib5iqwgfxexyd.onion][Hat.sh]]         |
+| [[https://lt.cleberg.net][LibreTranslate]] | A translation engine                              | [[http://nxw6545qeepw2s2kngowsxbcizjcxyimn7dq2bpvr3sqabsu2juj6gyd.onion][LibreTranslate]] |
+| [[https://mz.cleberg.net/][Mazanoke]]       | A local image optimizer that runs in your browser | [[http://ltawlmsk6vhrig2awwshnduiv45anelx3thepkd6xh4n2s4jxu7wyrid.onion][Mazanoke]]       |
+| [[https://office.cleberg.net/][Office]]         | The world's smallest office suite                 | [[http://uwtjz6pof52bzdkj242mub77ls2ji3qiznbsuoir235rxynqxadpghid.onion][Office]]         |
+| [[https://search.cleberg.net/][SearXNG]]        | A privacy-respecting, open metasearch engine      | [[http://txwk667ks3vh76r2mfqiot2wdptentsne64nu6qam63zbpzbmhtkvnid.onion][SearXNG]]        |
+| [[https://send.cleberg.net/][Send]]           | Simple, private file sharing                      | [[http://6jcf5qh2yg4axi42nbbcijglvoag74z7oq7xikqueebeb5vykj22miqd.onion][Send]]           |
+| [[https://slash.cleberg.net/][Slash]]          | Bookmark and link sharing platform                | [[http://svfj2zs33g572utlou6kx7uamhwen4nxdzvfetnhwjqs4mmdgoayc7qd.onion][Slash]]          |
diff --git a/content/services/index.org b/content/services/index.org
index baf11ae..c85afe4 100644
--- a/content/services/index.org
+++ b/content/services/index.org
@@ -1,5 +1,6 @@
 #+title: services
 #+slug: index
+#+options: toc:nil
 
 * Alternative Front-Ends/Proxies
 
diff --git a/publish.el b/publish.el
index 3849e5b..fb5c39b 100644
--- a/publish.el
+++ b/publish.el
@@ -23,7 +23,7 @@
  :theme nil
  :template-vars '(("site_name"        . "seijaku")
                   ("site_owner"       . "Christian Cleberg <hello@cleberg.net>")
-                  ("site_description" . "Stillness in the middle of it all.")))
+                  ("site_description" . "Stillness amidst the chaos.")))
 
 ;; Define routes for rendering content
 
@@ -85,13 +85,21 @@
  :output ".build/salary/{{ slug }}.html"
  :url "/salary/{{ slug }}.html")
 
 ;; Services page route
 (weblorg-route
- :name "services"
- :input-pattern "content/services/*.org"
+ :name "guides"
+ :input-pattern "content/guides/*.org"
  :template "page.html"
- :output ".build/services/{{ slug }}.html"
- :url "/services/{{ slug }}.html")
+ :output ".build/guides/{{ slug }}.html"
+ :url "/guides/{{ slug }}.html")
+
+;; Apps page route
+(weblorg-route
+ :name "apps"
+ :input-pattern "content/apps/*.org"
+ :template "page.html"
+ :output ".build/apps/{{ slug }}.html"
+ :url "/apps/{{ slug }}.html")
 
 ;; Now page route
 (weblorg-route
@@ -101,14 +109,6 @@
  :output ".build/now/{{ slug }}.html"
  :url "/now/{{ slug }}.html")
 
-;; About page route
-(weblorg-route
- :name "about"
- :input-pattern "content/about/*.org"
- :template "page.html"
- :output ".build/about/{{ slug }}.html"
- :url "/about/{{ slug }}.html")
-
 ;; Uses page route
 (weblorg-route
  :name "uses"
@@ -85,13 +85,21 @@
  :url "/salary/{{ slug }}.html")
 
-;; Services page route
+;; Guides page route
 (weblorg-route